@@ -113,13 +113,13 @@ they will be documented as producing the modern parse, and the code
 modified to produce this parse if necessary.
 
 The functionality that parses string literals (the C<parse> argument to
-C<new()>) was introduced in version [%% next_version $$], and should be
-considered experimental. It is a bit of a kluge in any case, especially
-in the appropriateness of class names to this use. But the actual
-parsing of a Perl string literal is not too different than the parsing
-of an C<s///> replacement string, so I thought that if someone wanted
-a string literal parse badly enough to deal with the kluginess I could
-provide it fairly easily.
+C<new()>) was introduced in version 0.045, and should be considered
+experimental. It is a bit of a kluge in any case, especially in the
+appropriateness of class names to this use. But the actual parsing of a
+Perl string literal is not too different than the parsing of an C<s///>
+replacement string, so I thought that if someone wanted a string literal
+parse badly enough to deal with the kluginess I could provide it fairly
+easily.
 
 =head1 METHODS
 
@@ -143,7 +143,7 @@ use PPIx::Regexp::Tokenizer;
 use PPIx::Regexp::Util qw{ __choose_tokenizer_class __instance };
 use Scalar::Util qw{ refaddr };
 
-our $VERSION = '0.047';
+our $VERSION = '0.050';
 
 =head2 new
 
@@ -237,17 +237,41 @@ The default is C<'regex'>.
 
 This option is passed on to the tokenizer, where it specifies whether
 postfix dereferences are recognized in interpolations and code. This
-experimental feature was introduced in Perl 5.19.5. The default is the
-value of C<$PPIx::Regexp::Tokenizer::DEFAULT_POSTDEREF>, which is false
-by default.
+experimental feature was introduced in Perl 5.19.5.
 
-If postfix dereferencing becomes mainstream, the default value of
-C<$PPIx::Regexp::Tokenizer::DEFAULT_POSTDEREF> will become true.
+The default is the value of
+C<$PPIx::Regexp::Tokenizer::DEFAULT_POSTDEREF>, which is true. When
+originally introduced this was false, but was documented as becoming
+true when and if postfix dereferencing became mainstream. The  intent to
+mainstream was announced with Perl 5.23.1, and became official (so to
+speak) with Perl 5.24.0, so the default became true with L<PPIx::Regexp>
+0.049_01.
 
 Note that if L<PPI|PPI> starts unconditionally recognizing postfix
 dereferences, this argument will immediately become ignored, and will be
 put through a deprecation cycle and removed.
 
+=item strict boolean
+
+This option is passed on to the tokenizer and lexer, where it specifies
+whether the parse should assume C<use re 'strict'> is in effect.
+
+The C<'strict'> pragma was introduced in Perl 5.22, and its
+documentation says that it is experimental, and that there is no
+commitment to backward compatibility. The same applies to the
+parse produced when this option is asserted. Also, the usual caveat
+applies: if C<use re 'strict'> ends up being retracted, this option and
+all related functionality will be also.
+
+Given the nature of C<use re 'strict'>, you should expect that if you
+assert this option, regular expressions that previously parsed without
+error might no longer do so. If an element ends up being declared an
+error because this option is set, its C<perl_version_introduced()> will
+be the Perl version at which C<use re 'strict'> started rejecting these
+elements.
+
+The default is false.
+
 =item trace number
 
 If greater than zero, this option causes trace output from the parse.
@@ -287,7 +311,7 @@ is it supported.
 
 	my $lexer = PPIx::Regexp::Lexer->new( $tokenizer, %args );
 	my @nodes = $lexer->lex();
-	my $self = $class->SUPER::_new( @nodes );
+	my $self = $class->SUPER::__new( @nodes );
 	$self->{source} = $content;
 	$self->{failures} = $lexer->failures();
 	$self->{effective_modifiers} =
@@ -337,7 +361,7 @@ any objects specified are removed from the cache.
     our $DISABLE_CACHE;		# Leave this undocumented, at least for
 				# now.
 
-    sub _cache_size {
+    sub __cache_size {
 	return scalar keys %cache;
     }
 
@@ -575,7 +599,9 @@ sub perl_version_removed {
     defined $v
 	and $v <= 5.021001
 	and return $v;
-    '??' eq $self->delimiters()
+    defined( my $delim = $self->delimiters() )
+	or return $v;
+    '??' eq $delim
 	and '' eq $self->type()->content()
 	and return '5.021001';
     return $v;
