@@ -65,9 +65,6 @@ C<< $elem->asserted( 'd' ) >> would return true, since in the absence of
 an explicit C<l> or C<u> this class considers the C<^> to explicitly
 assert C<d>.
 
-B<Note> that if this is retracted before Perl 5.14 is released, this
-support will disappear. See L<PPIx::Regexp/NOTICE> for some explanation.
-
 =head1 METHODS
 
 This class provides the following public methods. Methods not documented
@@ -89,7 +86,7 @@ use PPIx::Regexp::Constant qw{
     MODIFIER_GROUP_MATCH_SEMANTICS
 };
 
-our $VERSION = '0.041';
+our $VERSION = '0.050';
 
 # Define modifiers that are to be aggregated internally for ease of
 # computation.
@@ -105,6 +102,19 @@ foreach my $value ( values %aggregate ) {
     $de_aggregate{$value}++;
 }
 
+use constant TOKENIZER_ARGUMENT_REQUIRED => 1;
+
+sub __new {
+    my ( $class, $content, %arg ) = @_;
+
+    my $self = $class->SUPER::__new( $content, %arg )
+	or return;
+
+    $arg{tokenizer}->modifier_modify( $self->modifiers() );
+
+    return $self;
+}
+
 =head2 asserts
 
  $token->asserts( 'i' ) and print "token asserts i";
@@ -163,6 +173,51 @@ sub __asserts {
 
 sub can_be_quantified { return };
 
+{
+    my %explanation = (
+	'm'	=> 'm: ^ and $ match within string',
+	'-m'	=> '-m: ^ and $ match only at ends of string',
+	's'	=> 's: . can match newline',
+	'-s'	=> '-s: . can not match newline',
+	'i'	=> 'i: do case-insensitive matching',
+	'-i'	=> '-i: do case-sensitive matching',
+	'x'	=> 'x: ignore whitespace and comments',
+	'-x'	=> '-x: regard whitespace as literal',
+	'p'	=> 'p: provide ${^PREMATCH} etc (pre 5.20)',
+	'-p'	=> '-p: no ${^PREMATCH} etc (pre 5.20)',
+	'a'	=> 'a: restrict non-Unicode classes to ASCII',
+	'aa'	=> 'aa: restrict non-Unicode classes & ASCII-Unicode matches',
+	'd'	=> 'd: match using default semantics',
+	'l'	=> 'l: match using locale semantics',
+	'u'	=> 'u: match using Unicode semantics',
+	'n'	=> 'n: parentheses do not capture',
+	'-n'	=> '-n: parentheses capture',
+	'c'	=> 'c: preserve current position on match failure',
+	'g'	=> 'g: match repeatedly',
+	'e'	=> 'e: substitution string is an expression',
+	'ee'	=> 'ee: substitution is expression to eval()',
+	'o'	=> 'o: only interpolate once',
+	'r'	=> 'r: aubstitution returns modified string',
+    );
+
+    sub explain {
+	my ( $self ) = @_;
+	my @rslt;
+	my %mods = $self->modifiers();
+	if ( defined( my $val = delete $mods{match_semantics} ) ) {
+	    push @rslt, $explanation{$val};
+	}
+	foreach my $key ( sort keys %mods ) {
+	    if ( my $val = $mods{$key} ) {
+		push @rslt, $explanation{ $key x $val };
+	    } else {
+		push @rslt, $explanation{ "-$key" };
+	    }
+	}
+	return wantarray ? @rslt : join '; ', @rslt;
+    }
+}
+
 =head2 match_semantics
 
  my $sem = $token->match_semantics();
@@ -312,7 +367,20 @@ sub __aggregate_modifiers {
 	# distinguish between s/.../.../e and s/.../.../ee. But the
 	# modifiers can be randomized (that is, /eie is the same as
 	# /eei), so we reorder the content first.
-	$content = join '', sort split qr{}smx, $content;
+
+	# The following line is WRONG because it ignores the
+	# significance of '-'. This bug was introduced in version 0.035,
+	# specifically by the change that handled multi-character
+	# modifiers.
+	# $content = join '', sort split qr{}smx, $content;
+	# The following is better because it re-orders the modifiers
+	# separately. It does not recognize multiple dashes as
+	# representing an error (though it could!), and modifiers that
+	# are both asserted and negated (e.g. '(?i-i:foo)') are simply
+	# considered to be negated (as Perl does as of 5.20.0).
+	$content = join '-',
+	    map { join '', sort split qr{}smx }
+	    split qr{-}smx, $content;
 	my $value = 1;
 	while ( $content =~ m/ ( ( [[:alpha:]-] ) \2* ) /smxg ) {
 	    if ( '-' eq $1 ) {
@@ -347,15 +415,6 @@ sub __PPIX_TOKEN__recognize {
     );
 }
 
-# After the token is made, figure out what it asserts or negates.
-
-sub __PPIX_TOKEN__post_make {
-    my ( $self, $tokenizer ) = @_;
-    defined $tokenizer
-	and $tokenizer->modifier_modify( $self->modifiers() );
-    return;
-}
-
 {
 
     # Called by the tokenizer to modify the current modifiers with a new
@@ -401,7 +460,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2015 by Thomas R. Wyant, III
+Copyright (C) 2009-2016 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
